<p align="center">
  <a href="http://nestjs.com/" target="blank"><img src="https://nestjs.com/img/logo_text.svg" width="320" alt="Nestipy Logo" /></a>
</p>

[circleci-image]: https://img.shields.io/circleci/build/github/nestjs/nest/master?token=abc123def456
[circleci-url]: https://circleci.com/gh/nestjs/nest

  <p align="center">A progressive <a href="http://python.org" target="_blank">Python</a> framework for building efficient and scalable server-side applications.</p>
## Description

[Nestipy](https://github.com/tsiresymila/nestipy) 

## Installation

```bash
$ pip install -r requirements.txt
```

## Running the app

```bash
# development
$ python main.py
```

## Support

Nestipy is an MIT-licensed open source project. It can grow thanks to the sponsors and support by the amazing backers. If you'd like to join them, please [read more here](https://docs.nestipy.com/support).

## Stay in touch

- Author - [Tsiresy Mila](https://tsiresymila.vercel.app.com)
- Website - [https://nestipy.com](https://nestipy.com/)

## License

Nest is [MIT licensed](LICENSE).